@@ -1,10 +1,10 @@
 '''
 Utility functions.
 '''
-import os
-import sys
 import logging
 from pathlib import Path
+from contextlib import contextmanager,redirect_stderr,redirect_stdout
+from os import devnull
 from collections.abc import MutableMapping
 # from numpy_groupies.aggregate_numpy import aggregate
 import numpy as np
@@ -453,26 +453,19 @@ class ChainedAssignment:
     def __exit__(self, *args):
         pd.options.mode.chained_assignment = self.saved_swcw
 
-class HiddenPrints:
-    '''
-    Context manager to temporarily disable printing. Source: https://stackoverflow.com/a/45669280/17333120. Usage:
-        with HiddenPrints():
-            --code with no printing--
-        with HiddenPrints(False):
-            --code with printing--
-    '''
-    def __init__(self, hidden=True):
-        self.hidden = hidden
-
-    def __enter__(self):
-        if self.hidden:
-            self._original_stdout = sys.stdout
-            sys.stdout = open(os.devnull, 'w')
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        if self.hidden:
-            sys.stdout.close()
-            sys.stdout = self._original_stdout
+# @contextmanager
+# def HiddenPrints(hidden=True):
+#     '''
+#     Context manager to temporarily disable printing. Source: https://stackoverflow.com/a/52442331/17333120. Usage:
+#         with HiddenPrints():
+#             --code with no printing--
+#         with HiddenPrints(False):
+#             --code with printing--
+#     '''
+#     if hidden:
+#         with open(devnull, 'w') as fnull:
+#             with redirect_stderr(fnull) as err, redirect_stdout(fnull) as out:
+#                 yield (err, out)
 
 loggers = {}
 
